@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9775 2017-02-22 00:04:34Z David $
+# $Id: __init__.py 9861 2017-04-14 16:33:10Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-02-22 08:04:34 +0800 (Wed, 22 Feb 2017) $
-# $Revision: 9775 $
+# $Date: 2017-04-15 00:33:10 +0800 (Sat, 15 Apr 2017) $
+# $Revision: 9861 $
 
 import os
 import sys
@@ -290,6 +290,8 @@ def attachSettings(settingsDict):
             k: {'true': True, 'false': False}[v.lower()],
         })
     )
+    # Update back to variable if user specified DEBUG. 
+    DEBUG = settingsDict['DEBUG']
     #=========================================================================
 
     #=========================================================================
@@ -492,6 +494,12 @@ def attachSettings(settingsDict):
             'MEDIA_ROOT' : os.path.join(projectPath, 'media'),
             'MEDIA_URL' : '/media/',
         }
+
+        if settingsDict['SERVER_MODE'] == settingsDict['DEVELOPMENT']:
+            warnings.warn("%s '%s'" % (
+                colored("Cannot locate STATIC_URL", 'yellow', attrs=['bold']),
+                colored("Please run server with arg --insecure under the \
+                development mode if DEBUG=False.", 'cyan', attrs=['bold'])))
     else:
         staticDefaults = {
             'STATICFILES_DIRS': (
@@ -690,8 +698,8 @@ def attachSettings(settingsDict):
                         settingsDict,
                         settingsDict['IUNO_MEMBER_FACEBOOK_LOGIN_ENABLE'],
                         settingsDict['IUNO_MEMBER_GMAIL_LOGIN_ENABLE'],
-                        settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE'],
-                        settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE']
+                        settingsDict['IUNO_MEMBER_MSN_LIVE_LOGIN_ENABLE'],
+                        settingsDict['IUNO_MEMBER_YAHOO_LOGIN_ENABLE']
                     )
     else: # IUNO_MEMBER_ENABLE = False
         warnPackageDisable('Iuno.member', settingsDict, iunoMemberDefaults)
