@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# $Id: __init__.py 9775 2017-02-22 00:04:34Z David $
+# $Id: __init__.py 9840 2017-04-02 02:58:40Z David $
 #
 # Copyright (c) 2015 Nuwa Information Co., Ltd, All Rights Reserved.
 #
@@ -12,8 +12,8 @@
 # limitations under the License.
 #
 # $Author: David $ (last)
-# $Date: 2017-02-22 08:04:34 +0800 (Wed, 22 Feb 2017) $
-# $Revision: 9775 $
+# $Date: 2017-04-02 10:58:40 +0800 (Sun, 02 Apr 2017) $
+# $Revision: 9840 $
 
 import os
 import sys
@@ -220,7 +220,6 @@ def attachShopURLs(settings, urlpatterns):
     urlpatterns += patterns('',
         (r'^i18n/', include('django.conf.urls.i18n')),
         (r'', include(shop.urls)),
-
     )
 
 def attachPaypalURLs(settings, urlpatterns):
@@ -231,13 +230,16 @@ def attachPaypalURLs(settings, urlpatterns):
     @param settings Django project's settings module.
     @param urlpatterns urlpatterns in urls.py.
     """
+    import views
 
     from django.conf.urls import url, include, patterns
     from paypal.express.dashboard.app import application
 
     urlpatterns += patterns('',
-        (r'^checkout/payment-details/', include('paypal.express.urls')),
-        (r'^shop/dashboard/paypal/express/', include(application.urls)),
-
+        
+        url(r'^shop/dashboard/paypal/express/', include(application.urls)),
+        url(r'^checkout/paypal/place-order/(?P<basket_id>\d+)/$',
+            views.SuccessResponseView.as_view(), name='paypal-place-order'),
+        url(r'^checkout/paypal/', include('paypal.express.urls')),
     )
 
